#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.1.0
visibility:             public
id:                     taffybar-4.1.0-AESuWpFJmLf9TGbum7Pyop
key:                    taffybar-4.1.0-AESuWpFJmLf9TGbum7Pyop
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    819aafab5e806c55f4d3191945668285
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.1.0-AESuWpFJmLf9TGbum7Pyop
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl wayland-client
    m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie
    Xft cairo m dl fontconfig m expat m Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m harfbuzz-gobject
    harfbuzz m freetype dl bz2 png16 m m brotlidec brotlicommon
    graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m
    pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-BAQzSp6bLIdCYRoVAlxcni
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx
    ansi-terminal-1.1-Jn1rGzu1G9XELC9vQ6NFDR base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-ZW0r2gxsao1PdW3Ct9TSq
    containers-0.6.7 data-default-0.7.1.3-GWfmROYPtdX1tMV8eki8U8
    dbus-1.3.3-JgrYnEmupD3H5gnUIrXv6R
    dbus-hslogger-0.1.0.1-40aPa0kx7oS44oXnaqbDD6 directory-1.3.8.5
    dyre-0.9.2-7Le4jOC75atJ5aaluPymeQ
    either-5.0.3-EodhgrOgz8CAJ5Cxs0XVgv
    enclosed-exceptions-1.0.3-GFqhAX7iRyrBJLexDGcttR filepath-1.4.300.1
    fsnotify-0.4.4.0-33OmXoHw1QoDrttCymGbQb
    gi-cairo-connector-0.1.1-EUYVXQHSU1c4X6vM9Urk3N
    gi-cairo-render-0.1.2-42MfhyfW9jU5qo3pgyZd6J
    gi-gdk-3.0.29-4wlkl6Icf0447zQrmaYpk0
    gi-gdkpixbuf-2.0.32-ICkbtFm37VxB25RrwPaQWp
    gi-gdkx11-3.0.16-IYT81ZCKqXJ1JG997wEKr0
    gi-glib-2.0.30-BOwAfobOneXETjm3S9nCS0
    gi-gtk-3.0.43-2ZoAaKAgNZCHOcxTA1eaSu
    gi-gtk-hs-0.3.17-Ipr4PHUMVpnJQt1fWhnqi
    gi-pango-1.0.30-L6PqjDhOWjCEw29p15Xj5n
    gtk-sni-tray-0.1.8.1-2riGT3BvdMDov26C78MxW
    gtk-strut-0.1.3.2-L8ZSS9H6PG5JbjeRrZLkse
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    hslogger-1.3.2.0-HQWbmSBxC6N1FRMTnI22pF
    http-client-0.7.19-4NdB1UhXjPHpnfAoWeuwI
    http-client-tls-0.3.6.4-9nWpV5E7PWG8UoCj5iZhrt
    http-conduit-2.3.9.1-CJjQ4Pj4smCJ23yhm2qXQz
    http-types-0.12.4-CXiZJUbLhJFHeSLHvVo6Rt
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw parsec-3.1.16.1
    process-1.6.19.0 rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    safe-0.3.21-HhLYFpBFMp3DB0hN62u10D
    scotty-0.22-2k6W2BhcV93GneCISpuG1z
    split-0.2.5-47epspW4k5y1JnAPK4u1Hj
    status-notifier-item-0.3.2.0-KAd00oDkbVO3b3xZRUXjmm stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv transformers-0.6.1.0
    tuple-0.3.0.2-8uKi46pFy1K3NaM31ujn4V unix-2.8.4.0
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xdg-desktop-entry-0.1.1.4-BgGwurxTr4n4YtYhQFp7YJ
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
    xmonad-0.18.0-JPJIjDyiQZHH81nJ2Ryw58

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-taffybar-z-testlib
version:              4.1.0
package-name:         taffybar
lib-name:             testlib
id:                   taffybar-4.1.0-G4nS5wBgS1n2R7A5VOu1YQ-testlib
key:                  taffybar-4.1.0-G4nS5wBgS1n2R7A5VOu1YQ-testlib
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             http://github.com/taffybar/taffybar
synopsis:             A desktop bar similar to xmobar, but with more GUI
category:             System
abi:                  27134a75bdd2e84d09d3251e40ab2468
exposed-modules:
    System.Taffybar.Test.DBusSpec System.Taffybar.Test.UtilSpec
    System.Taffybar.Test.XvfbSpec TestLibSpec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/taffybar
hs-libraries:         HStaffybar-4.1.0-G4nS5wBgS1n2R7A5VOu1YQ-testlib
depends:
    QuickCheck-2.15.0.1-6vCsVQySFFl51cZw5lFSZI
    attoparsec-0.14.4-AJVRZfhVOVzJGMVFtBGw8r base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-GWfmROYPtdX1tMV8eki8U8
    dbus-1.3.3-JgrYnEmupD3H5gnUIrXv6R
    extra-1.7.16-53b454gmz0kFA1gZEklCYN filepath-1.4.300.1
    hslogger-1.3.2.0-HQWbmSBxC6N1FRMTnI22pF
    hspec-2.11.6-IlRWveztQv7FKLJUUrEAWs
    taffybar-4.1.0-AESuWpFJmLf9TGbum7Pyop text-2.0.2
    typed-process-0.2.13.0-5XonszuoAja4pQkGLa2SAh unix-2.8.4.0
    unliftio-0.2.25.1-8PFdViM4kSw68msSMSHlHp
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:         /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

